/*   v          Ver 0.00   */
/*                            */
/*                            */
/*   by Atsushi  2000/12/12   */


import java.util.Calendar;
import java.util.Date;
import com.nttdocomo.io.ConnectionException;
import com.nttdocomo.ui.*;


public class ClockCanvas extends Canvas
{
	/*   ---   萔   ---   */

	public final static int ID_TIMER=0;

	/*   ---   Field   ---   */

	private IApplication application;

	private Image clock;
	private ShortTimer timer;
	private boolean analog;

	/*   ---   Constructor   ---   */

	public ClockCanvas(IApplication application)
	{
		this.application=application;
		
		setSoftLabel(SOFT_KEY_1,"Quit");
		setSoftLabel(SOFT_KEY_2,"Digital");
		
		loadImage();
		timer=ShortTimer.getShortTimer(this,ID_TIMER,100,true);
		analog=true;
	}

	/*   ---      ---   */

	private void loadImage()
	{
		MediaImage image;
	
		try {
			image=MediaManager.getImage("resource:///clock.gif");
			image.use();
			clock=image.getImage();
		}
		catch (ConnectionException e)
		{
		}
	}

	/*   ---   Jn   ---   */

	public void start()
	{
		timer.start();
	}

	/*   ---   `   ---   */

	public void paint(Graphics g)
	{
		Calendar calendar;
		String time,str;
		Font font;
		int th,dx,dy;
	
		g.lock();
		g.clearRect(0,0,getWidth(),getHeight());
		
		calendar=Calendar.getInstance();
		calendar.setTime(new Date());
		
		if (analog)
		{
			g.drawImage(clock,
			    getWidth ()/2-clock.getWidth ()/2,
			    getHeight()/2-clock.getHeight()/2);
			g.setColor(g.getColorOfName(Graphics.BLACK));
			
			th=2*FixedPointMath.PI*calendar.get(Calendar.HOUR_OF_DAY)/12+
			   2*FixedPointMath.PI*calendar.get(Calendar.MINUTE)/60  /12;
			dx=(FixedPointMath.sin(th)*20)>>FixedPointMath.DECIMAL_ACCURACY;
			dy=(FixedPointMath.cos(th)*20)>>FixedPointMath.DECIMAL_ACCURACY;
			g.drawLine(
			    getWidth()/2   ,getHeight()/2,
			    getWidth()/2+dx,getHeight()/2-dy);
			g.drawLine(
			    getWidth()/2   ,getHeight()/2+1,
			    getWidth()/2+dx,getHeight()/2-dy);
			
			th=2*FixedPointMath.PI*calendar.get(Calendar.MINUTE)/60;
			dx=(FixedPointMath.sin(th)*32)>>FixedPointMath.DECIMAL_ACCURACY;
			dy=(FixedPointMath.cos(th)*32)>>FixedPointMath.DECIMAL_ACCURACY;
			g.drawLine(
			    getWidth()/2   ,getHeight()/2,
			    getWidth()/2+dx,getHeight()/2-dy);
			g.drawLine(
			    getWidth()/2   ,getHeight()/2+1,
			    getWidth()/2+dx,getHeight()/2-dy);
			
			th=2*FixedPointMath.PI*calendar.get(Calendar.SECOND)/60;
			dx=(FixedPointMath.sin(th)*38)>>FixedPointMath.DECIMAL_ACCURACY;
			dy=(FixedPointMath.cos(th)*38)>>FixedPointMath.DECIMAL_ACCURACY;
			g.drawLine(
			    getWidth()/2   ,getHeight()/2,
			    getWidth()/2+dx,getHeight()/2-dy);
		}
		else
		{
			time=calendar.get(Calendar.HOUR_OF_DAY)+":";
			str="0"+Integer.toString(calendar.get(Calendar.MINUTE));
			time=time+str.substring(str.length()-2,str.length())+":";
			str="0"+Integer.toString(calendar.get(Calendar.SECOND));
			time=time+str.substring(str.length()-2,str.length());
			
			font=Font.getDefaultFont();
			g.setColor(g.getColorOfName(Graphics.BLACK));
			g.drawString(time,
			    getWidth ()/2-font.stringWidth(time)/2,
			    getHeight()/2-font.getHeight()/2+font.getAscent());
		}
		
		g.unlock(true);
	}

	/*   ---   Cxg   ---   */

	public void processEvent(int type,int param)
	{
		if ((type==Display.TIMER_EXPIRED_EVENT) && (param==ID_TIMER))
		{
			paint(getGraphics());
		}
		if ((type==Display.KEY_PRESSED_EVENT) && (param==Display.KEY_SOFT2))
		{
			if (analog)
			{
				setSoftLabel(SOFT_KEY_2,"Analog");
			}
			else
			{
				setSoftLabel(SOFT_KEY_2,"Digital");
			}
			
			analog=!analog;
		}
		
		if ((type==Display.KEY_PRESSED_EVENT) && (param==Display.KEY_SOFT1))
		{
			timer.stop();
			timer.dispose();
			
			application.terminate();
		}
	}
}
